; This relies on the ability of the assembler to read labels and put data bytes
; and all that other good stuff. No actual assembly is used here, just data.

;;;;;;;;;;;;;;;;;
;;  envelopes  ;;
;;;;;;;;;;;;;;;;;
;; 10 - Jump to position XX
;; FF - Stop envelope

; Each byte is just simply written to register 0 of whatever channel is using the
; envelope, after one of the useless bits being masked out so commands (yep, all
; two of them) could exist. Triangle channel completely ignores envelopes.
; It's *highly* recommended that the first envelope is a silent one.

envelopes
 dc.w	env_blank, env_lead1, env_nse_hat, env_nse_hat2, env_nse_snare, env_lead2
 dc.w sq4sound, sq4sound_cont
env_blank:
 hex	00 FF
env_lead1:
 hex	0F 0D 0B 09 07 05 04 04 04 04 05 05 06 06 06 06 05 05 10 06
env_nse_hat:
 hex	0F 0C 00 FF
env_nse_hat2:
 hex	0F 0B 07 03 FF
env_nse_snare:
 hex	0F 08 0C 06 04 03 02 02 01 01 00 FF
env_lead2:
 hex	8C 8E 8F 8E 8C 8A 89 88 87 86 85 84 FF
sq4sound:
	hex 41 4a 4d 4d 4d 4a 43 43 43 43 43 43 43 43 43 43 ff
sq4sound_cont:
	hex 41 4a 4d 4d 4d 4a 43 43 43 43 43 43 43 43 43 43
	hex 46 46 46 46 46 43 43 43 43 43 43 43 43 43 43 43 10 00
;;;;;;;;;;;;;;;;;;
;;  song table  ;;
;;;;;;;;;;;;;;;;;;
; This determines what song is assigned to what value when loading songs
songs
;	dc.w silence
	dc.w title_song, story_song, controls_song, credits_song, gp_song, win_song, all_song

;;;;;;;;;;;;;
;;  songs  ;;
;;;;;;;;;;;;;
;; C8 XX - silent rest for XX cycles
;; C0 XX - do nothing (just extend the note for another XX cycles)
;; C1 XX - precut (cut the note XX cycles before it ends)
;; C2 XX - set envelope to XX
;; C3 YY XX ZZ - jump to YYXX, ZZ times
;; C4 YY XX - jump to YYXX
;; C5 XX - set detune to XX (01-7F up, 80-FF down, 00 none)
;; C6 XX - decrease envelope volume by XX
;; C7 XX - set pitch bend to XX (01-7F down, 80-FE up, 00 none)
;; C9 XX - set tempo-independent pitch bend (functions the same as C7)
;; FF - Track end (the track stops playing here)

; The first 4 words in the list are the pointer for square 1, square 2, tri, noise
; in that order, followed by a byte that defines the tempo. Lower values are
; slower, higher are faster, 00 is infinitely slow, making the song stop.
; If you don't use a particular channel for a song, just put 0000 as the pointer.
; All four channels can be used at once. It's *highly* recommended that you reserve
; one song in your playlist to be a silent song.
;silence
;	dc.w $0000, $0000, $0000, $0000
;	dc $00
gp_song
	dc.w gp_song_sq1, gp_song_sq2, gp_song_tri, gp_song_nse
	dc $f0
win_song
	dc.w win_song_sq1, win_song_sq2, win_song_tri, win_song_nse
	dc $f0
story_song
	dc.w story_song_sq1, story_song_sq2, story_song_tri, story_song_nse
	dc $80
controls_song
	dc.w controls_song_sq1, controls_song_sq2, controls_song_tri, controls_song_nse
	dc $c0
credits_song
	dc.w credits_song_sq1, credits_song_sq2, credits_song_tri, credits_song_nse
	dc $f0
title_song
	dc.w title_song_sq1, title_song_sq2, title_song_tri, title_song_nse
	dc $f0
all_song
	dc.w all_song_sq1, all_song_sq2, all_song_tri, all_song_nse
	dc $c0
;; Song data is just <note> <duration> for each note, or <command> <data>... for
; commands (see table above). For <note>, the higher nybble is the actual note
; (the scale begins with A, so 0x is A, 1x is A#, 2x is B, etc), and the lower
; nybble is the octave. The tracks are state machines, so whatever commands you
; apply (like envelope, detune, pitch bend, etc) will stick until you change them,
; or until a new song is loaded.


gp_song_sq1
	hex c8 80
gp_song_sq1_1
	hex c2 06
	hex 20 10 20 10 20 08 40 08 c8 08
	hex 20 10 20 10 20 08 40 08 50 08 70 08 90 08
	dc $c3
	dc.w gp_song_sq1_1
	dc $04
	hex c8 80
gp_song_sq1_2
	hex c2 06
	hex 20 08 20 08 20 08 c8 08 50 08 c8 08 20 08 c8 18
	hex 20 08 c8 08 50 08 40 08 30 08 c8 08
	dc $c3
	dc.w gp_song_sq1_2
	dc $03
gp_song_sq1_3
;	.byte $c2 01
	hex 22 18 52 18 92 10 23 18 92 18 52 10
	hex 22 18 52 18 92 10 52 10 c8 10 c2 05 50 08 40 08 30 08 c8 08
	hex c2 06
	hex 22 18 52 18 92 10 23 18 92 18 92 10
	hex 52 18 92 18 52 10 22 10 c8 10 50 08 40 08 30 08 c8 08
	dc $c3
	dc.w gp_song_sq1_3
	dc $01
gp_song_sq1_4
	hex c2 05
	hex 20 08 20 08 20 08 c8 08 50 08 c8 08 20 08 c8 18
	hex 20 08 c8 08 50 08 40 08 30 08 c8 08
	dc $c3
	dc.w gp_song_sq1_4
	dc $03
gp_song_sq1_5
	hex 50 08 50 08 50 08 50 08 50 10 90 10 b0 18 90 18
	hex 50 10
	dc $c3
	dc.w gp_song_sq1_5
	dc $03
	dc $c4
	dc.w gp_song_sq1
	dc $ff

gp_song_sq2
	hex c8 80 c8 80
gp_song_sq2_1
	hex c2 01
	hex 60 10 60 10 60 08 80 08 c8 08
	hex 60 10 60 10 60 08 80 08 90 08 b0 08 11 08
	dc $c3
	dc.w gp_song_sq2_1
	dc $03
	hex c8 80
gp_song_sq2_2
	hex c2 06
	hex 90 08 90 08 90 08 c8 08 01 08 c8 08 90 08 c8 18
	hex 90 08 c8 08 01 08 b0 08 a0 08 c8 08
	dc $c3
	dc.w gp_song_sq2_2
	dc $0f
gp_song_sq2_3
	hex 90 08 90 08 90 08 90 08 90 10 01 10 31 18 01 18
	hex 90 10
	dc $c3
	dc.w gp_song_sq2_3
	dc $03
	dc $c4
	dc.w gp_song_sq2
	dc $ff

gp_song_tri
	hex c8 80 c0 80
gp_song_tri1
	hex c1 01
	hex 22 08 22 08 22 08 22 08 22 08 43 08 42 08
	hex 22 08 22 08 22 08 22 08 22 08 42 08 52 08 72 08 92 08
	dc $c3
	dc.w gp_song_tri1
	dc $04
gp_song_tri2
	hex c1 00
	hex 22 20 52 10 22 30 52 08 42 08 32 10
	dc $c3
	dc.w gp_song_tri2
	dc $0f
gp_song_tri3
	hex 52 08 52 08 52 08 52 08 52 10 92 10 b2 18 92 18
	hex 52 10
	dc $c3
	dc.w gp_song_tri3
	dc $03
	dc $c4
	dc.w gp_song_tri
	dc $ff

gp_song_nse
	hex c2 04
	hex 0d 08 00 08 0d 08 00 08 0e 08 00 08 00 08
	hex 0d 08 00 08 0d 08 00 08 00 08 0e 08 00 08 00 08 00 08
	dc $c3
	dc.w gp_song_nse
	dc $05
	hex c8 80
gp_song_nse1
	hex 0e 08 0e 08 0e 08 00 08 0d 08 00 08 0e 08 00 08
	hex 00 08 00 08 0e 08 00 08 0d 08 00 08 00 08 00 08
	dc $c3
	dc.w gp_song_nse1
	dc $0f
gp_song_nse2
	hex 0e 08 0e 08 0e 08 0e 08 0d 08 0e 08 0e 08 0e 08
	hex 0e 08 0e 08 0e 08 0e 08 0d 08 0e 08 0e 08 0e 08
	dc $c3
	dc.w gp_song_nse2
	dc $03
	dc $c4
	dc.w gp_song_nse
	dc $ff

win_song_sq1
	hex c8 30
	hex c2 06
	hex 02 10 72 10 22 10 92 20 52 10 03 30
	hex ff
win_song_sq2
	hex c8 30
	hex c2 06
	hex 42 10 b2 10 62 10 13 20 92 10 43 30
	hex ff
win_song_tri
	hex c8 30
	hex 02 10 72 10 22 10 92 20 52 10 03 30
	hex ff
win_song_nse
	hex c8 30
	hex c2 04
	hex 0e 10 0d 10 0e 10 0d 20 0e 10 0d 38 00 10 00 10 00 10
	hex ff

story_song_sq1
	hex c2 06
	hex 51 08 c8 08 81 08 51 08 c8 08 81 08 71 08 51 08
	hex 81 08 71 08 51 08 10 08 10 08 10 08 00 10
	dc $c4
	dc.w story_song_sq1
story_song_sq2
	hex c2 07
	hex 53 80 23 80 83 80 23 80
	dc $c4
	dc.w story_song_sq2
story_song_tri
	hex 51 80 21 80 81 80 91 80
	dc $c4
	dc.w story_song_tri
story_song_nse
	hex c2 02 00 10 c2 05 00 10
	dc $c4
	dc.w story_song_nse

controls_song_sq1
	hex c2 06
;	hex c8 80
	hex 50 04 50 04 50 04 50 04 50 04 50 04
	hex 72 01 72 01 72 01 72 01 72 01 72 01 72 01 72 01
	hex 50 04 50 04 50 04 50 04 60 04 60 04 60 04 60 04 60 04 60 04
	hex 82 01 82 01 82 01 82 01 82 01 82 01 82 01 82 01
	hex 60 04 60 04 60 04 60 04 70 04 70 04 70 04 70 04 70 04 70 04
	hex 92 01 92 01 92 01 92 01 92 01 92 01 92 01 92 01
	dc $c4
	dc.w controls_song_sq1
controls_song_sq2
	hex c2 06
	hex 52 18 73 08 52 10 62 18 83 08 62 10
	hex 72 18 93 08
	dc $c4
	dc.w controls_song_sq2
controls_song_tri
	hex 52 10 53 08 73 08 52 10 62 10 63 08 83 08 62 10
	hex 72 10 73 08 93 08
	dc $c4
	dc.w controls_song_tri
controls_song_nse
	hex c2 05
	hex 00 10 0e 08 0e 08 00 10 00 10 0e 08 0e 08 00 10
	hex 00 10 0e 08 0e 08
	dc $c4
	dc.w controls_song_nse

credits_song_sq1
	hex c2 06
	hex 30 08 20 08 30 08 c8 18
	hex 50 08 40 08 50 08 c8 18
	hex 60 08 50 08 50 08 40 08
	dc $c4
	dc.w credits_song_sq1
credits_song_sq2
	hex c2 06
	hex 31 08 21 08 31 08 c8 18
	hex 51 08 41 08 51 08 c8 18
	hex 61 08 51 08 51 08 41 08
	dc $c4
	dc.w credits_song_sq2
credits_song_tri
	hex c8 80 c8 80
credits_song_tri1
	hex c1 07
	hex 34 08
	dc $c3
	dc.w credits_song_tri1
	dc $1f
	dc $c4
	dc.w credits_song_tri
credits_song_nse
	hex c8 80
credits_song_nse1
	hex c2 04
	hex 0e 08 00 08 00 08 00 08 0d 08 00 08 00 08 00 08
	dc $c4
	dc.w credits_song_nse1

title_song_sq1
	hex c2 06
	hex 50 08 00 08 40 08 00 08 20 08 00 08 40 08 00 08
	hex 60 08 50 08 40 08 20 08 50 08 40 08 20 08 00 08
	hex 50 08 00 08 40 08 00 08 20 08 00 08 40 08 00 08
	hex 60 08 50 08 40 08 20 08 20 08 40 08 00 10
	dc $c4
	dc.w title_song_sq1
	hex ff
title_song_sq2
	hex c2 06
	hex 21 40 51 40 41 40
	hex 61 08 51 08 41 08 21 08 21 08 41 08 01 10
	hex 51 40 41 40 21 40
	hex a1 08 91 08 81 08 61 08 61 08 81 08 41 08 40 08
	dc $c4
	dc.w title_song_sq2
title_song_tri
	hex c1 04
	hex 21 10 22 10 21 10 22 10
	dc $c4
	dc.w title_song_tri
	hex ff
title_song_nse
	hex c2 04
	hex 0e 08 00 08 00 08 00 08 0d 08 00 08 00 08 00 08
	dc $c4
	dc.w title_song_nse
	hex ff

all_song_sq1
	hex c8 30
	hex c2 06
	hex 50 10 30 10 00 20
	hex ff
all_song_sq2
	hex c8 30
	hex c2 06
	hex 80 10 60 10 30 20
	hex ff
all_song_tri
	hex c8 30
	hex 52 10 32 10 02 20
	hex ff
all_song_nse
	hex c8 30
	hex c2 04
	hex 00 10 00 10 00 10
	hex ff






; Sound effects - Absolutely everything that applies for the music and songs
; applies here too, except sound effects have their own playlist and their
; own envelope table. Also, all sound effects play at tempo 100, which is
; impossible for music, since music tempo only goes up to FF. When a sound
; effect is playing, it'll interrupt the corresponding channels of the music,
; and then when the sound effect is finished, the music channels it hogged will
; be audible again.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  sound effect envelopes  ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

sfxenvelopes
 dc.w	sfxenv1
sfxenv1
 hex	8F 8D 88 8F 8E 8D 8C 8B 8A 89 88 87 86 85 84 83 82 81 80 FF

;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  sound effect table  ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;
sounds
	dc.w sfx_silence ;, pause_jingle, end_level_score, got_virus, player_hit, targeting
;	.addr target_explosion, time_expire, teleport_sound, cant_teleport, title_start
;;;;;;;;;;;;;;;;;;;;;
;;  sound effects  ;;
;;;;;;;;;;;;;;;;;;;;;
sfx_silence
 dc.w	$0000,$0000,$0000,$0000


;got_virus
;	.addr 0000, got_virus_sq2 0000 0000
;got_virus_sq2
; hex 24 01 43 01 53 01 63 01 73 01 83 01 93 01 a3 01 ff

;player_hit
;	.addr 0000, player_hit_sq2, player_hit_tri 0000
;player_hit_sq2
; hex 30 01 45 04 35 01 25 01 15 01 05 01 b4 01 a4 01 94 01
; hex 84 01 74 01 64 01 54 01 44 01 34 01 24 01 14 01 04 01
; hex 03 04 02 08 01 10 ff
;player_hit_tri
; hex 31 01 45 04 35 01 25 01 15 01 05 01 b4 01 a4 01 94 01
; hex 84 01 74 01 64 01 54 01 44 01 34 01 24 01 14 01 04 01
; hex 03 04 02 08 01 10 ff

;pause_jingle
;	.addr pause_sq1 0000 0000 0000
;pause_sq1
; hex 33 08 03 08 33 08 63 08 ff

;end_level_score
;	.addr end_level_score_sq1 0000 0000 0000
;end_level_score_sq1
; hex 64 08 ff

;targeting
;	.addr targeting_sq1 0000 0000 0000 0000
;targeting_sq1
; hex 35 01 ff

;target_explosion
;	.addr 0000 0000 0000,target_ex_nse
;target_ex_nse
; hex 0f 10 ff ; 0f 10 ff

;time_expire
;	.addr time_expire_sq1 0000 0000 0000
;time_expire_sq1
; hex b4 04 63 04 ff

;teleport_sound
;	.addr teleport_sound_sq1, teleport_sound_sq2 0000 0000
;teleport_sound_sq1
; hex 30 01 70 01 31 01 71 01 32 01 72 01 ff
;teleport_sound_sq2
; hex 24 01 34 01 44 01 54 01 64 01 74 01 ff

;cant_teleport
;	.addr cant_teleport_sq1 0000 0000 0000
;cant_teleport_sq1
; hex 30 08 30 08 ff

;title_start
;	.addr title_start_sq1,title_start_sq2,title_start_tri,title_start_nse
;title_start_sq1
; hex c8 18 a4 08 ff
;title_start_sq2
; hex 31 01 41 01 51 01 61 01 71 01 81 01 91 01 a1 01 b1 01 32 01
; hex c8 08 34 08 ff
;title_start_tri
; hex 31 10 ff
;title_start_nse
; hex 0f 10 ff ; 0f 10 ff
